@@ -7,6 +7,7 @@ import tempfile
 import shutil
 from pathlib import Path
 from src.utils.path_manager_singleton import PathManagerSingleton
+from src.utils.functions import verify_config_options
 
 from src.core.bt_graph import BTGraph
 
@@ -24,14 +25,20 @@ def render(config_path: str = "mt_config.json"):
 
     config = read_config_file(config_path)
 
+    mt_path_manager = PathManagerSingleton()
+    mt_path_manager.setup(config)
+
     g = BTGraph()
     g.build_graph(config)
 
+    verify_config_options(config, g)
+
     project_name = config.get("name")
 
     for view_name, views in config.get("views").items():
         formatted_views = [
-            os.path.join(config.get("rootFolder"), view) for view in views["packages"]
+            os.path.join(config.get("rootFolder"), view)
+            for view in views["packages"]
         ]
         plantuml_diagram_creator_sub_domains(
             g.root_module,
@@ -52,22 +59,26 @@ def render_diff(config_path: str = "mt_config.json"):
         print("Created temporary directory:", tmp_dir)
         config = read_config_file(config_path)
 
-        fetch_git_repo(tmp_dir, config["github"]["url"], config["github"]["branch"])
+        fetch_git_repo(
+            tmp_dir, config["github"]["url"], config["github"]["branch"]
+        )
 
-        my_file = Path(tmp_dir + "/mt_config.json")
+        my_file = Path(os.path.join(tmp_dir, config_path))
         if not my_file.is_file():
-            shutil.copyfile(config_path, tmp_dir + "/mt_config.json")
+            shutil.copyfile(config_path, os.path.join(tmp_dir, config_path))
 
-        config_git = read_config_file(tmp_dir + "/mt_config.json")
+        config_git = read_config_file(os.path.join(tmp_dir, config_path))
 
         path_manager = PathManagerSingleton()
         path_manager.setup(config, config_git)
 
         g_git = BTGraph()
         g_git.build_graph(config_git)
+        verify_config_options(config_git, g_git)
 
         g = BTGraph()
         g.build_graph(config)
+        verify_config_options(config, g)
 
         project_name = config.get("name")
 
@@ -107,10 +118,7 @@ def read_config_file(config_path):
 
     jsonschema.validate(instance=config, schema=schema)
 
-    config["_config_path"] = os.path.dirname(config_path)
-
-    mt_path_manager = PathManagerSingleton()
-    mt_path_manager.setup(config)
+    config["_config_path"] = os.path.dirname(os.path.abspath(config_path))
 
     return config
 
